@@ -2,13 +2,14 @@ use strict;
 use Module::Build;
 
 my $build = Module::Build->new(
-    create_makefile_pl	=> 'traditional',
+    create_makefile_pl	=> 'small',
     license		=> 'perl',
     module_name		=> 'Win32::Security::EFS',
     requires		=> {
         'Win32'			=> 0.24,
         'Win32::API'	=> 0.41,
         'File::Spec'	=> 3.05,
+        'Module::Build' => 0.2,
     },
     reccomends => {
     },
